/***************************************************************************
                          input.cpp  -  description
                             -------------------
    begin                : Sat May 5 2001
    copyright            : (C) 2001 by Volker Schroer
    email                : DL1KSV@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/

#include "input.h"
#include <errno.h>
Input::Input(int ptt)
{
fd = -1;
serial=ptt;
}
Input::~Input()
{
}

 /** Opens the Device named Device for reading */

bool Input::open_Device_read(QString Device)
{
fd = open(Device,O_RDONLY);
if (fd > 0)
	return true;
else
	return false;
}

  /** Closes the open Device */
bool Input::close_Device()
{

if (fd >= 0)
	close(fd);
fd = -1;
return true;
}



	

